==> gbook-0.15.tar.bz2: gbook/gbook.i18n-en.php <==
<?php

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "name",
'f_origin'        => "origin",
'f_ip'            => "ip",
'f_browser'       => "browser",
'f_email'         => "email",
'f_homepage'      => "homepage",
'f_captcha'       => "captcha",
'f_entry'         => "entry",
'f_ip'            => "ip",
'f_browser'       => "browser",

# buttons
'b_submit'        => "submit",
'b_reply'         => "reply",
'b_change'        => "change",
'b_delete'        => "delete",
'b_reset'         => "reset",

# misc
'headline'        => "Guestbook",
'hl_create'       => "Creating a new entry:",
'hl_modify'       => "Modifying an entry:",
'new_entry'       => "Welcome in this guestbook. [{{fullurl:$this->myAddPage|action=add}} '''Here'''] you can add new entries.",
'entry_okay'      => "Okay, your entry was added ;)",
'delete_okay'     => "Okay, the entry was deleted.",
'change_okay'     => "Okay, the entry was changed.",
'show_entries'    => "Show entries.",
'captcha_desc'    => "Type please the letters and numbers from the small graphic under it.",
'captcha_fail'    => "Sorry, your captcha isn't correct!",

'err_name'        => "Sorry, your name is needed!",
'err_entry'       => "Sorry, your entry seems empty!",
'err_noentry'     => "Sorry, this entry doesn't exist!",
'err_captcha'     => "Sorry, the captcha is epmty!",
'err_blocked'     => "Sorry, you are not permitted to edit this guestbook!",
'err_spam'        => "Sorry, no spamming please."
);

?>

==> gbook-0.17.tar.bz2: gbook/gbook.i18n-en.php <==
<?php

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "name",
'f_origin'        => "origin",
'f_ip'            => "ip",
'f_browser'       => "browser",
'f_email'         => "email",
'f_homepage'      => "homepage",
'f_captcha'       => "captcha",
'f_entry'         => "entry",
'f_ip'            => "ip",
'f_browser'       => "browser",

# buttons
'b_submit'        => "submit",
'b_reply'         => "reply",
'b_change'        => "change",
'b_delete'        => "delete",
'b_reset'         => "reset",

# misc
'headline'        => "Guestbook",
'hl_create'       => "Creating a new entry:",
'hl_modify'       => "Modifying an entry:",
'new_entry'       => "Welcome in this guestbook. [{{fullurl:$this->myAddPage|action=add}} '''Here'''] you can add new entries.",
'entry_okay'      => "Okay, your entry was added ;)",
'delete_okay'     => "Okay, the entry was deleted.",
'change_okay'     => "Okay, the entry was changed.",
'show_entries'    => "Show entries.",
'captcha_desc'    => "Type please the letters and numbers from the small graphic under it.",
'captcha_fail'    => "Sorry, your captcha isn't correct!",

'err_name'        => "Sorry, your name is needed!",
'err_entry'       => "Sorry, your entry seems empty!",
'err_noentry'     => "Sorry, this entry doesn't exist!",
'err_captcha'     => "Sorry, the captcha is empty!",
'err_blocked'     => "Sorry, you are not permitted to edit this guestbook!",
'err_spam'        => "Sorry, no spamming please."
);

?>
